/* Copyright (C) 1995, 1997 Free Software Foundation, Inc.
This file is part of GNU Fortran libU77 library.

This library is free software; you can redistribute it and/or modify it
under the terms of the GNU Library General Public License as published
by the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

GNU Fortran is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with GNU Fortran; see the file COPYING.LIB.  If
not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */


/* via f2c from Fortran */

#include "f2c.h"

integer G77_lnblnk_0 (char *str, ftnlen str_len)
{
    integer ret_val;
    integer i_len();

    for (ret_val = str_len; ret_val >= 1; --ret_val) {
	if (*(unsigned char *)&str[ret_val - 1] != ' ') {
	    return ret_val;
	}
    }
    return ret_val;
}
